@@ -13,6 +13,9 @@
 #ifndef LIBC_MUSL
 # define LIBC_MUSL 4
 #endif
+#ifndef STACK_USE_CUMULATIVE_ARGS_INIT
+# define STACK_USE_CUMULATIVE_ARGS_INIT 0
+#endif
 #ifndef HEAP_TRAMPOLINES_INIT
 # define HEAP_TRAMPOLINES_INIT 0
 #endif
